@@ -5,7 +5,7 @@ import re
 import configparser
 
 from i3pystatus import IntervalModule, formatp
-from i3pystatus.core.util import lchop, TimeWrapper
+from i3pystatus.core.util import lchop, TimeWrapper, make_bar
 from i3pystatus.core.desktop import DesktopNotification
 
 
@@ -49,16 +49,23 @@ class Battery:
         return self._percentage("_DESIGN" if design else "") * 100
 
     def status(self):
-        if self.consumption():
+        if self.consumption() > 0.1 and self.percentage() < 99.9:
             return "Discharging" if self.battery_info["STATUS"] == "Discharging" else "Charging"
         else:
             return "Full"
 
+    def consumption(self, val):
+        return val if val > 0.1 else 0
+
 
 class BatteryCharge(Battery):
+    def __init__(self, bi):
+        bi["CHARGE_FULL"] = bi["CHARGE_FULL_DESIGN"] if bi["CHARGE_NOW"] > bi["CHARGE_FULL"] else bi["CHARGE_FULL"]
+        super().__init__(bi)
+
     def consumption(self):
         if "VOLTAGE_NOW" in self.battery_info and "CURRENT_NOW" in self.battery_info:
-            return self.battery_info["VOLTAGE_NOW"] * self.battery_info["CURRENT_NOW"]  # V * A = W
+            return super().consumption(self.battery_info["VOLTAGE_NOW"] * self.battery_info["CURRENT_NOW"])  # V * A = W
         else:
             return -1
 
@@ -73,12 +80,13 @@ class BatteryCharge(Battery):
             else:
                 return -1
         else:
-            return (self.battery_info["CHARGE_FULL"] - self.battery_info["CHARGE_NOW"]) / self.battery_info["CURRENT_NOW"] * 60
+            return (self.battery_info["CHARGE_FULL"] - self.battery_info["CHARGE_NOW"]) / self.battery_info[
+                "CURRENT_NOW"] * 60
 
 
 class BatteryEnergy(Battery):
     def consumption(self):
-        return self.battery_info["POWER_NOW"]
+        return super().consumption(self.battery_info["POWER_NOW"])
 
     def _percentage(self, design):
         return self.battery_info["ENERGY_NOW"] / self.battery_info["ENERGY_FULL" + design]
@@ -88,7 +96,8 @@ class BatteryEnergy(Battery):
             # Wh / W = h * 60 min = min
             return self.battery_info["ENERGY_NOW"] / self.battery_info["POWER_NOW"] * 60
         else:
-            return (self.battery_info["ENERGY_FULL"] - self.battery_info["ENERGY_NOW"]) / self.battery_info["POWER_NOW"] * 60
+            return (self.battery_info["ENERGY_FULL"] - self.battery_info["ENERGY_NOW"]) / self.battery_info[
+                "POWER_NOW"] * 60
 
 
 class BatteryChecker(IntervalModule):
@@ -104,11 +113,13 @@ class BatteryChecker(IntervalModule):
     * `{consumption (Watts)}` — current power flowing into/out of the battery
     * `{status}`
     * `{battery_ident}` — the same as the setting
+    * `{bar}` —bar displaying the percentage graphically
     """
 
     settings = (
         ("battery_ident", "The name of your battery, usually BAT0 or BAT1"),
         "format",
+        ("not_present_text", "Text displayed if the battery is not present. No formatters are available"),
         ("alert", "Display a libnotify-notification on low battery"),
         "alert_percentage",
         ("alert_format_title", "The title of the notification, all formatters can be used"),
@@ -116,7 +127,10 @@ class BatteryChecker(IntervalModule):
         ("path", "Override the default-generated path"),
         ("status", "A dictionary mapping ('DIS', 'CHR', 'FULL') to alternative names"),
         ("color", "The text color"),
+        ("full_color", "The full color"),
+        ("charging_color", "The charging color"),
         ("critical_color", "The critical color"),
+        ("not_present_color", "The not present color."),
     )
     battery_ident = "BAT0"
     format = "{status} {remaining}"
@@ -125,13 +139,17 @@ class BatteryChecker(IntervalModule):
         "DIS": "DIS",
         "FULL": "FULL",
     }
+    not_present_text = "Battery not present"
 
     alert = False
     alert_percentage = 10
     alert_format_title = "Low battery"
     alert_format_body = "Battery {battery_ident} has only {percentage:.2f}% ({remaining:%E%hh:%Mm}) remaining!"
     color = "#ffffff"
+    full_color = "#00ff00"
+    charging_color = "#00ff00"
     critical_color = "#ff0000"
+    not_present_color = "#ffffff"
 
     path = None
 
@@ -144,7 +162,14 @@ class BatteryChecker(IntervalModule):
         urgent = False
         color = self.color
 
-        battery = Battery.create(self.path)
+        try:
+            battery = Battery.create(self.path)
+        except FileNotFoundError:
+            self.output = {
+                "full_text": self.not_present_text,
+                "color": self.not_present_color,
+            }
+            return
 
         fdict = {
             "battery_ident": self.battery_ident,
@@ -152,6 +177,7 @@ class BatteryChecker(IntervalModule):
             "percentage_design": battery.percentage(design=True),
             "consumption": battery.consumption(),
             "remaining": TimeWrapper(0, "%E%h:%M"),
+            "bar": make_bar(battery.percentage()),
         }
 
         status = battery.status()
@@ -165,8 +191,10 @@ class BatteryChecker(IntervalModule):
                     color = self.critical_color
             else:
                 fdict["status"] = "CHR"
+                color = self.charging_color
         else:
             fdict["status"] = "FULL"
+            color = self.full_color
 
         if self.alert and fdict["status"] == "DIS" and fdict["percentage"] <= self.alert_percentage:
             DesktopNotification(
@@ -180,7 +208,7 @@ class BatteryChecker(IntervalModule):
         fdict["status"] = self.status[fdict["status"]]
 
         self.output = {
-            "full_text": formatp(self.format, **fdict).strip(),
+            "full_text": formatp(self.format, **fdict),
             "instance": self.battery_ident,
             "urgent": urgent,
             "color": color,
