@@ -1,4 +1,3 @@
-
 from i3pystatus.core.settings import SettingsBase
 from i3pystatus.core.threading import Manager
 from i3pystatus.core.util import convert_position
@@ -16,6 +15,8 @@ class Module(SettingsBase):
             if "name" not in self.output:
                 self.output["name"] = self.__name__
             self.output["instance"] = str(id(self))
+            if (self.output.get("color", "") or "").lower() == "#ffffff":
+                del self.output["color"]
             json.insert(convert_position(self.position, json), self.output)
 
     def run(self):
@@ -45,7 +46,7 @@ class IntervalModuleMeta(type):
         super(IntervalModuleMeta, cls).__init__(name, bases, namespace)
         if not hasattr(cls, 'settings'):
             cls.settings = tuple()
-        if not 'interval' in SettingsBase.flatten_settings(cls.settings):
+        if 'interval' not in SettingsBase.flatten_settings(cls.settings):
             cls.settings += ('interval', )
 
 
