@@ -1,4 +1,3 @@
-
 import collections
 import functools
 import re
@@ -51,9 +50,14 @@ def partition(iterable, limit, key=lambda x: x):
 def round_dict(dic, places):
     """
     Rounds all values in a dict containing only numeric types to `places` decimal places.
-    """
-    for key, value in dic.items():
-        dic[key] = round(value, places)
+    If places is None, round to INT.
+    """    
+    if places is None:
+        for key, value in dic.items():
+            dic[key] = round(value)
+    else:
+        for key, value in dic.items():
+            dic[key] = round(value, places)
 
 
 class ModuleList(collections.UserList):
@@ -177,6 +181,7 @@ def formatp(string, **kwargs):
         They also have a string property containing associated text (empty for
         all tokens but String tokens).
         """
+
         class Token:
             string = ""
 
@@ -333,13 +338,16 @@ def require(predicate):
         :py:func:`internet`
 
     """
+
     def decorator(method):
         @functools.wraps(method)
         def wrapper(*args, **kwargs):
             if predicate():
                 return method(*args, **kwargs)
             return None
+
         return wrapper
+
     return decorator
 
 
@@ -354,3 +362,38 @@ def internet():
         return True
     except OSError:
         return False
+
+def make_bar(percentage):
+    """
+    Draws a bar made of unicode box characters.
+
+    :param percentage: A value between 0 and 100
+    :returns: Bar as a string
+    """
+
+    bars = [' ', '▏', '▎', '▍', '▌', '▋', '▋', '▊', '▊', '█']
+    tens = int(percentage / 10)
+    ones = int(percentage) - tens * 10
+    result = tens * '█'
+    if(ones >= 1):
+        result = result + bars[ones]
+    result = result + (10 - len(result)) * ' '
+    return result
+
+
+def user_open(url_or_command):
+    """Open the specified paramater in the web browser if a URL is detected,
+    othewrise pass the paramater to the shell as a subprocess. This function
+    is inteded to bu used in on_leftclick()/on_rightclick() events.
+
+    :param url_or_command: String containing URL or command
+    """
+    from urllib.parse import urlparse
+    scheme = urlparse(url_or_command).scheme
+    if scheme == 'http' or scheme == 'https':
+        import webbrowser
+        webbrowser.open(url_or_command)
+    else:
+        import subprocess
+        subprocess.Popen(url_or_command, shell=True)
+
