@@ -2,7 +2,6 @@ from i3pystatus import IntervalModule
 
 
 class Load(IntervalModule):
-
     """
     Shows system load
     """
@@ -12,7 +11,7 @@ class Load(IntervalModule):
         ("format",
          "format string used for output. {avg1}, {avg5} and {avg15} are the load average of the last one, five and fifteen minutes, respectively. {tasks} is the number of tasks (i.e. 1/285, which indiciates that one out of 285 total tasks is runnable)."),
         ("color", "The text color"),
-        ("critical_limit", "Limit under witch one the battery is critical"),
+        ("critical_limit", "Limit above which the load is considered critical"),
         ("critical_color", "The critical color"),
     )
 
