@@ -1,16 +1,11 @@
-
 import socket
+from os.path import basename
 
 from i3pystatus import IntervalModule, formatp
 from i3pystatus.core.util import TimeWrapper
 
 
-def format_time(seconds):
-    return "{}:{:02}".format(*divmod(int(seconds), 60)) if seconds else ""
-
-
 class MPD(IntervalModule):
-
     """
     Displays various information from MPD (the music player daemon)
 
@@ -19,6 +14,7 @@ class MPD(IntervalModule):
     * `{title}` — (the title of the current song)
     * `{album}` — (the album of the current song, can be an empty string (e.g. for online streams))
     * `{artist}` — (can be empty, too)
+    * `{filename}` — (file name with out extension and path; empty unless title is empty)
     * `{song_elapsed}` — (Position in the currently playing song, uses `TimeWrapper`_, default is `%m:%S`)
     * `{song_length}` — (Length of the current song, same as song_elapsed)
     * `{pos}` — (Position of current song in playlist, one-based)
@@ -36,21 +32,21 @@ class MPD(IntervalModule):
         ("host"),
         ("port", "MPD port"),
         ("format", "formatp string"),
-        ("status", "Dictionary mapping pause, play and stop to output")
+        ("status", "Dictionary mapping pause, play and stop to output"),
+        ("color", "The color of the text"),
     )
 
     host = "localhost"
     port = 6600
     s = None
     format = "{title} {status}"
-    format_sparse = None
     status = {
         "pause": "▷",
         "play": "▶",
         "stop": "◾",
     }
+    color = "#FFFFFF"
 
-    vol = 100
 
     def _mpd_command(self, sock, command):
         try:
@@ -70,10 +66,6 @@ class MPD(IntervalModule):
         except Exception as e:
             return None
 
-    def init(self):
-        if not self.format_sparse:
-            self.format_sparse = self.format
-
     def run(self):
         try:
             status = self._mpd_command(self.s, "status")
@@ -83,7 +75,7 @@ class MPD(IntervalModule):
                 "len": int(status["playlistlength"]),
                 "status": self.status[status["state"]],
                 "volume": int(status["volume"]),
-
+                
                 "title": currentsong.get("Title", ""),
                 "album": currentsong.get("Album", ""),
                 "artist": currentsong.get("Artist", ""),
@@ -92,26 +84,28 @@ class MPD(IntervalModule):
                 "bitrate": int(status.get("bitrate", 0)),
 
             }
+            if not fdict["title"]:
+                fdict["filename"] = '.'.join(
+                        basename(currentsong["file"]).split('.')[:-1])
+            else:
+                fdict["filename"] = ""
             self.output = {
                 "full_text": formatp(self.format, **fdict).strip(),
+                "color": self.color,
             }
         except Exception as e:
-            self.output = {"full_text": "error connecting MPD"}
+            self.output = {"full_text": "error connecting MPD",
+                           "color": self.color}
 
     def on_leftclick(self):
         try:
             self._mpd_command(self.s, "pause %i" %
-                              (0 if self._mpd_command(self.s, "status")["state"] == "pause" else 1))
+                                      (0 if self._mpd_command(self.s, "status")["state"] == "pause" else 1))
         except Exception as e:
             pass
 
     def on_rightclick(self):
         try:
-            vol = int(self._mpd_command(self.s, "status")["volume"])
-            if vol == 0:
-                self._mpd_command(self.s, "setvol %i" % self.vol)
-            else:
-                self.vol = vol
-                self._mpd_command(self.s, "setvol 0")
+            self._mpd_command(self.s, "next")
         except Exception as e:
             pass
