@@ -1,15 +1,14 @@
-
 import basiciw
 
+from i3pystatus.core.util import make_bar
 from i3pystatus.network import Network
 
 
 class Wireless(Network):
-
     """
     Display network information about a interface.
 
-    Requires the PyPI packages `netifaces-py3` and `basiciw`.
+    Requires the PyPI packages `netifaces` and `basiciw`.
 
     This is based on the network module, so all options and formatters are
     the same, except for these additional formatters and that detached_down doesn't work.
@@ -17,6 +16,7 @@ class Wireless(Network):
     * `{essid}` — ESSID of currently connected wifi
     * `{freq}` — Current frequency
     * `{quality}` — Link quality in percent
+    * `{quality_bar}` —Bar graphically representing link quality
     """
 
     interface = "wlan0"
@@ -34,6 +34,7 @@ class Wireless(Network):
             else:
                 fdict["quality"] = quality["quality"]
             fdict["quality"] *= 100
+            fdict["quality_bar"] = make_bar(fdict["quality"])
         else:
             fdict["essid"] = ""
             fdict["freq"] = fdict["quality"] = 0.0
